@@ -450,7 +450,7 @@ void ModelTest::data()
     // Check that the alignment is one we know about
     QVariant textAlignmentVariant = model->data(model->index(0, 0), Qt::TextAlignmentRole);
     if (textAlignmentVariant.isValid()) {
-        int alignment = textAlignmentVariant.toInt();
+        unsigned int alignment = textAlignmentVariant.toUInt();
         Q_ASSERT(alignment == (alignment & (Qt::AlignHorizontal_Mask | Qt::AlignVertical_Mask)));
         Q_UNUSED(alignment);
     }
